==> ufs_0.4.3.tar.gz: ufs/README.md <==

<!-- badges: start -->

[![Pipeline
status](https://gitlab.com/r-packages/ufs/badges/prod/pipeline.svg)](https://gitlab.com/r-packages/ufs/commits/prod)
[![Coverage
status](https://codecov.io/gl/r-packages/ufs/branch/prod/graph/badge.svg)](https://codecov.io/gl/r-packages/ufs?branch=prod)
[![Version on
CRAN](https://www.r-pkg.org/badges/version/ufs?color=brightgreen)](https://cran.r-project.org/package=ufs)
[![Monthly downloads on
CRAN](https://cranlogs.r-pkg.org/badges/last-month/ufs?color=brightgreen)](https://cran.r-project.org/package=ufs)
[![Total downloads on
CRAN](https://cranlogs.r-pkg.org/badges/grand-total/ufs?color=brightgreen)](https://cran.r-project.org/package=ufs)
<!-- badges: end -->

# <img src='img/hex-logo.png' align="right" height="200" /> ufs 📦

ufs: A leaner, cleaner version of the userfriendlyscience package

The pkgdown website for this project is located at
<https://r-packages.gitlab.io/ufs>.

## Installation

You can install the released version of `ufs` from
[CRAN](https://CRAN.R-project.org) with:

``` r
install.packages('ufs');
```

You can install the development version of `ufs` from
[GitLab](https://about.gitlab.com) with:

``` r
remotes::install_gitlab('r-packages/ufs');
```

If you want the even more cutting edge version, you can install from the
`dev` branch (as opposed to the default branch, `prod`) with:

``` r
remotes::install_gitlab('r-packages/ufs@dev');
```

(This is assuming you have the `remotes` packages installed; otherwise,
install that first using the `install.packages` function.)

==> ufs_0.5.10.tar.gz: ufs/README.md <==

<!-- badges: start -->

[![Pipeline
status](https://gitlab.com/r-packages/ufs/badges/prod/pipeline.svg)](https://gitlab.com/r-packages/ufs/-/commits/prod)
[![Coverage
status](https://codecov.io/gl/r-packages/ufs/branch/prod/graph/badge.svg)](https://app.codecov.io/gl/r-packages/ufs?branch=prod)
[![Version on
CRAN](https://www.r-pkg.org/badges/version/ufs?color=brightgreen)](https://cran.r-project.org/package=ufs)
[![Monthly downloads on
CRAN](https://cranlogs.r-pkg.org/badges/last-month/ufs?color=brightgreen)](https://cran.r-project.org/package=ufs)
[![Total downloads on
CRAN](https://cranlogs.r-pkg.org/badges/grand-total/ufs?color=brightgreen)](https://cran.r-project.org/package=ufs)
<!-- badges: end -->

# <img src='img/hex-logo.png' align="right" height="200" /> ufs 📦

ufs: A leaner, cleaner version of the userfriendlyscience package

The pkgdown website for this project is located at
<https://r-packages.gitlab.io/ufs>.

## Installation

You can install the released version of `ufs` from
[CRAN](https://CRAN.R-project.org) with:

``` r
install.packages('ufs');
```

You can install the development version of `ufs` from
[GitLab](https://about.gitlab.com) with:

``` r
remotes::install_gitlab('r-packages/ufs');
```

If you want the even more cutting edge version, you can install from the
`dev` branch (as opposed to the default branch, `prod`) with:

``` r
remotes::install_gitlab('r-packages/ufs@dev');
```

(This is assuming you have the `remotes` packages installed; otherwise,
install that first using the `install.packages` function.)
